16.134. cdist-type__rvm_gemset(7) — cdist 6.5.4 documentation

# 16.134. cdist-type__rvm_gemset(7)

## 16.134.1. NAME

cdist-type__rvm_gemset - Manage Ruby gems through rvm

## 16.134.2. DESCRIPTION

RVM is the Ruby enVironment Manager for the Ruby programming language.

## 16.134.3. REQUIRED PARAMETERS

user
  The remote user account to use
gemset
  The gemset to use
state
  Either "present" or "absent", defaults to "present".

## 16.134.4. OPTIONAL PARAMETERS

default
  Make the selected gemset the default

## 16.134.5. EXAMPLES

    # Install the rails gem in gemset ruby-1.9.3-p0@myset for user bill
    __rvm_gemset rails --gemset ruby-1.9.3-p0@myset --user bill --state present

    # Do the same and also make ruby-1.9.3-p0@myset the default gemset
    __rvm_gemset rails --gemset ruby-1.9.3-p0@myset --user bill \
                       --state present --default

    # Remove it
    __rvm_ruby rails --gemset ruby-1.9.3-p0@myset --user bill --state absent

## 16.134.6. SEE ALSO

cdist-type__rvm(7), cdist-type__rvm_gemset(7), cdist-type__rvm_ruby(7)

## 16.134.7. AUTHORS

Evax Software <contact@evax.fr>

## 16.134.8. COPYING

Copyright (C) 2012 Evax Software. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).